local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.Enemy, x.ActiveEnemy, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

local HasteCDs = {
	49016--[[Unholy Frenzy]],
	80353--[[Time Warp]],
	2825--[[Bloodlust]],
	32182--[[Heroism]],
	90355--[[Ancient Hysteria]],
	26297--[[Berserking]],
	3045--[[Rapid Fire]],
}

a.spells["Auto Shot"] = {
	ID = 75--[[Auto Shot]],
	EnemyTargetNeeded = 1,
	NotIfActive = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC
	end,
}

a.spells["Hunter's Mark"] = {
	ID = 1130--[[Hunter's Mark]],
	Debuff = 1130--[[Hunter's Mark]],
	EarlyRefresh = 5,
	CheckFirst = function(z)
		return not s.HasGlyph(53243--[[Glyph of Marked for Death]])
	end,
	EnemyTargetNeeded = 1,
}

a.spells["Aspect of the Hawk"] = {
	Type = "form",
	ID = 13165--[[Aspect of the Hawk]],
	Buff = 13165--[[Aspect of the Hawk]],
	BuffUnit = "player",
	NotWhileMoving = 1,
	CheckFirst = function(z)
		return not s.Moving("player")
	end,
}

a.spells["Aspect of the Fox while moving"] = {
	Type = "form",
	ID = 82661--[[Aspect of the Fox]],
	Buff = 82661--[[Aspect of the Fox]],
	BuffUnit = "player",
	CheckFirst = function(z)
		return s.Moving("player") and not IsMounted()
	end,
}

a.spells["Explosive Trap (AoE)"] = {
	ID = 13813--[[Explosive Trap]],
	CheckFirst = function(z)
		return s.InCombat()
	end,
	FlashColor = "Green",
	Continue = 1,
	NoRangeCheck = 1,
}

a.spells["Focus Fire"] = {
	ID = 82692--[[Focus Fire]],
	RequireBuff = 19623--[[Frenzy]],
	RequireStack = 5,
	RequireBuffUnit = "pet",
	CheckFirst = function(z)
		return s.InCombat()
	end,
}

a.spells["Serpent Sting"] = {
	ID = 1978--[[Serpent Sting]],
	MyDebuff = 1978--[[Serpent Sting]],
	Run = function(z)
		z.EarlyRefresh = s.CastTime(77767--[[Cobra Shot]])
	end,
	CheckFirst = function(z)
		return s.InCombat() and x.NoCC
	end,
	EnemyTargetNeeded = 1,
}

a.spells["Serpent Sting (MM)"] = {
	ID = 1978--[[Serpent Sting]],
	MyDebuff = 1978--[[Serpent Sting]],
	CheckFirst = function(z)
		return s.InCombat() and x.NoCC and s.Health("target") > 0 and s.HealthPercent("target") <= 90
	end,
	EnemyTargetNeeded = 1,
}

a.spells["Chimera Shot"] = {
	ID = 53209--[[Chimera Shot]],
	CheckFirst = function(z)
		return s.InCombat() and x.NoCC and s.Health("target") > 0 and s.HealthPercent("target") <= 90
	end,
	EnemyTargetNeeded = 1,
}

a.spells["Bestial Wrath"] = {
	ID = 19574--[[Bestial Wrath]],
	CheckFirst = function(z)
		return s.InCombat() and s.Power("player", SPELL_POWER_FOCUS) > 60
	end,
}

a.spells["Multi-Shot (AoE)"] = {
	ID = 2643--[[Multi-Shot]],
	CheckFirst = function(z)
		return s.InCombat()
	end,
	FlashColor = "Green",
	EnemyTargetNeeded = 1,
	Continue = 1,
}

a.spells["Steady Shot (AoE)"] = {
	ID = 56641--[[Steady Shot]],
	CheckFirst = function(z)
		local _, time = s.LastSpellTravelTime(2643--[[Multi-Shot]], "target")
		if not time then
			return false
		else
			return s.InCombat() and x.NoCC and (GetTime() - time ) < 2
		end
	end,
	FlashColor = "Green",
	EnemyTargetNeeded = 1,
	Continue = 1,
}

a.spells["Cobra Shot (AoE)"] = {
	ID = 77767--[[Cobra Shot]],
	CheckFirst = function(z)
		local _, time = s.LastSpellTravelTime(2643--[[Multi-Shot]], "target")
		if not time then
			return false
		else
			return s.InCombat() and x.NoCC and (GetTime() - time ) < 2
		end
	end,
	FlashColor = "Green",
	EnemyTargetNeeded = 1,
	Continue = 1,
}

a.spells["Kill Shot"] = {
	ID = 53351--[[Kill Shot]],
	CheckFirst = function(z)
		return s.InCombat() and x.NoCC
	end,
	EnemyTargetNeeded = 1,
}

a.spells["A Murder of Crows"] = {
	ID = 120657--[[A Murder of Crows]],
	CheckFirst = function(z)
		return s.InCombat() and not (s.BuffDuration(HasteCDs, "player") > 0) and not (s.BuffDuration(34692--[[The Beast Within]], "player") > 0)
	end,
	EnemyTargetNeeded = 1,
	NoRangeCheck = 1,
}

a.spells["Kill Command"] = {
	ID = 34026--[[Kill Command]],
	CheckFirst = function(z)
		return s.InCombat() and x.NoCC
	end,
	EnemyTargetNeeded = 1,
}

a.spells["Arcane Shot w/ Thrill of the Hunt"] = {
	ID = 3044--[[Arcane Shot]],
	RequireBuff = 34720--[[Thrill of the Hunt]],
	RequireBuffUnit = "player",
	CheckFirst = function(z)
		return s.InCombat() and x.NoCC
	end,
	EnemyTargetNeeded = 1,
}

a.spells["Arcane Shot (MM)"] = {
	ID = 3044--[[Arcane Shot]],
	RequireBuff = 34720--[[Thrill of the Hunt]],
	RequireBuffUnit = "player",
	CheckFirst = function(z)
		return s.InCombat() and x.NoCC and s.Health("target") > 0 and s.HealthPercent("target") <= 90 and not (s.BuffDuration(HasteCDs, "player") > 0) and ((s.Power("player", SPELL_POWER_FOCUS) >= 66) or (s.SpellCooldown(53209--[[Chimera Shot]]) >= 4))
	end,
	EnemyTargetNeeded = 1,
}

a.spells["Arcane Shot as focus dump"] = {
	ID = 3044--[[Arcane Shot]],
	CheckFirst = function(z)
		return s.InCombat() and x.NoCC and ((s.Power("player", SPELL_POWER_FOCUS) >= 69) or (s.BuffDuration(34692--[[The Beast Within]],"player") > 0))
	end,
	EnemyTargetNeeded = 1,
}

a.spells["Steady Shot w/ Steady Focus"] = {
	ID = 56641--[[Steady Shot]],
	CheckFirst = function(z)
		local duration = s.MyBuffDuration(53224--[[Steady Focus]], "player")
		return s.InCombat() and x.NoCC and duration > 0 and duration < 3
	end,
	EnemyTargetNeeded = 1,
}

a.spells["Steady Shot"] = {
	ID = 56641--[[Steady Shot]],
	CheckFirst = function(z)
		return s.InCombat() and x.NoCC
	end,
	EnemyTargetNeeded = 1,
}

a.spells["Cobra Shot"] = {
	ID = 77767--[[Cobra Shot]],
	CheckFirst = function(z)
		return s.InCombat() and x.NoCC
	end,
	EnemyTargetNeeded = 1,
}

a.spells["Rapid Fire"] = {
	ID = 3045--[[Rapid Fire]],
	CheckFirst = function(z)
		return s.InCombat() and x.NoCC and not (s.BuffDuration(HasteCDs, "player") > 0) and not (s.BuffDuration(34692--[[The Beast Within]], "player") > 0)
	end,
	EnemyTargetNeeded = 1,
	Continue = 1,
	NoGCD = 1,
	FlashColor = "Yellow",
}

a.spells["Readiness after Rapid Fire"] = {
	ID = 23989--[[Readiness]],
	CheckFirst = function(z)
		return s.InCombat() and x.NoCC and s.SpellCooldown(3045--[[Rapid Fire]]) > 0
	end,
	EnemyTargetNeeded = 1,
	Continue = 1,
	NoGCD = 1,
	FlashColor = "Yellow",
}

a.spells["Aimed Shot w/ Master Marksman"] = {
	ID = 19434--[[Aimed Shot]],
	RequireMyBuff = 82925--[[Ready, Set, Aim...]],
	RequireStack = 5,
	RequireBuffUnit = "player",
	CheckFirst = function(z)
		return s.InCombat() and x.NoCC
	end,
	EnemyTargetNeeded = 1,
}

a.spells["Aimed Shot over 90"] = {
	ID = 19434--[[Aimed Shot]],
	CheckFirst = function(z)
		return s.InCombat() and x.NoCC and s.Health("target") > 0 and s.HealthPercent("target") > 90
	end,
	EnemyTargetNeeded = 1,
}

a.spells["Aimed Shot as focus dump"] = {
	ID = 19434--[[Aimed Shot]],
	CheckFirst = function(z)
		return s.InCombat() and x.NoCC and s.BuffDuration(HasteCDs, "player") > 0 and ((s.SpellCooldown(53209--[[Chimera Shot]]) > 5) or (s.Power("player", SPELL_POWER_FOCUS) >= 90))
	end,
	EnemyTargetNeeded = 1,
}

a.spells["Call Pet"] = {
	ID = 883--[[Call Pet 1]],
	CheckFirst = function(z)
		return not x.PetAlive and not IsMounted()
	end,
	FlashID = {883--[[Call Pet 1]], 83242--[[Call Pet 2]], 83243--[[Call Pet 3]], 83244--[[Call Pet 4]], 83245--[[Call Pet 5]], 982--[[Revive Pet]]},
}

a.spells["Mend Pet"] = {
	ID = 136--[[Mend Pet]],
	CheckFirst = function(z)
		return x.PetAlive and s.Health("pet") > 0 and s.HealthPercent("pet") < 80
	end,
}

a.spells["Explosive Shot"] = {
	ID = 53301--[[Explosive Shot]],
	MyDebuffID = 53301--[[Explosive Shot]],
	EarlyRefresh = 1.9,
	CheckFirst = function(z)
		return s.InCombat() and x.NoCC
	end,
	EnemyTargetNeeded = 1,
}

a.spells["Black Arrow"] = {
	ID = 3674--[[Black Arrow]],
	MyDebuffID = 3674--[[Black Arrow]],
	CheckFirst = function(z)
		return s.InCombat() and x.NoCC
	end,
	EnemyTargetNeeded = 1,
}